==> nonebot_ark_record-1.0.tar.gz: nonebot_ark_record-1.0/nonebot_ark_record/ark/ark_style.py <==
"""_summary_
本文件控制绘图样式
非常不建议修改本文件中的内容
"""


"""输出图片的样式"""
#图像宽度
base_img_w = 1000
#不包括新干员信息的图像高度
base_img_h = 400

base_img_back_color = "#696969"#(125,125,125)#底图颜色
img_bcolor = '#828282'
title_fcolor = 'brown'
text_fcolor = 'black'
#
title_drawer_p = {
    'w':'',
    'h':'',
    'pos':(0,0),#直接0,0，可以不用调
    'back_img_w' :'',    
    'back_img_h' :'',
    'back_img_pos':(0,0)    
}

title_fsize_prop = 0.1
title_pos_prop = 0.1
title_p = {
    'fsize': title_fsize_prop*base_img_h,
    'color':'white'
}
title_p['pos']=(0.05*title_p['fsize'],0.1*title_p['fsize'])

sub_title_fsize_prop = 0.75
sub_title_pos_prop = 1.2
sub_title_p = {
    'fsize':sub_title_fsize_prop*title_p['fsize'],
    'color':text_fcolor,
    'pos':(title_p['pos'][0], sub_title_pos_prop*title_p['fsize'])
}

pie_p_pos_y = 1.2*(sub_title_p['fsize'] + title_p['fsize'])
x_step = 0.009*base_img_w#每个块之间的间隔

pie_p_title_fsize_prop = 0.14
pie_p_text_fsize_prop = 0.11
pie_p_percent_fsize_prop = 0.07
#设置字体大小时要考虑缩放

pie_star_p ={
    'h':240,
    'pos':(x_step, pie_p_pos_y),
    'title_fcolor':title_fcolor,
    'text_fcolor':text_fcolor,
    'percent_fcolor':text_fcolor,
    'radii': 12,
    'bcolor': img_bcolor
}
pie_star_p['w'] = pie_star_p['h']
pie_star_p['title_fsize'] = pie_star_p['h']*pie_p_title_fsize_prop
pie_star_p['text_fsize'] = pie_star_p['h']*pie_p_text_fsize_prop
pie_star_p['percent_fsize'] = pie_star_p['h']*pie_p_percent_fsize_prop

#直方图样式
histo_pool_p = {
    'pos':(pie_star_p['w']+pie_star_p['pos'][0]+x_step, pie_p_pos_y),
    'w':pie_star_p['h']*7/6,
    'h':pie_star_p['h'],
    'title_fsize':pie_star_p['title_fsize'],
    'title_fcolor':title_fcolor,
    'tick_fsize':pie_star_p['text_fsize'],
    'tick_fcolor':text_fcolor,
    'radii': 12,
    'bcolor':img_bcolor
}


#星级描述样式
desc_title_fsize_prop = 0.11
desc_text_fsize_prop = 0.09
desc_w_prop = 0.6
desc_star_p ={
    'parts':['title', 'text'],
    'bimage':{
        'w': pie_star_p['h']*0.8,
        'h': pie_star_p['h'],
        'radii': 12,#圆角半径
        'pos': (histo_pool_p['w']+histo_pool_p['pos'][0]+x_step, pie_p_pos_y),
        'bcolor':img_bcolor
    },
    'title':{
        'color':title_fcolor,
    },
    'text':{
        'color':text_fcolor,
    }
}
desc_star_p['title']['fsize'] = desc_title_fsize_prop * desc_star_p['bimage']['h']
desc_star_p['text']['fsize'] = desc_text_fsize_prop * desc_star_p['bimage']['h']
desc_star_p['title']['pos'] = (0.03*desc_star_p['bimage']['w'], 0.03*desc_star_p['bimage']['w'])
desc_star_p['text']['pos'] = (0.03*desc_star_p['bimage']['w'], 1.12*(desc_star_p['title']['pos'][1]+desc_star_p['title']['fsize']))
#水位情况

desc_shuiwei_p ={
    'parts':['title', 'text'],
    'bimage':{
        'w': pie_star_p['h']*0.95,
        'h': pie_star_p['h'],
        'radii': 12,#圆角半径
        'pos': (desc_star_p['bimage']['w']+desc_star_p['bimage']['pos'][0]+x_step, pie_p_pos_y),
        'bcolor':img_bcolor
    },
    'title':{
        'color':title_fcolor,
    },
    'text':{
        'color':text_fcolor,
    }
}
desc_shuiwei_p['title']['fsize'] = desc_title_fsize_prop * pie_star_p['h']
desc_shuiwei_p['text']['fsize'] = desc_text_fsize_prop *pie_star_p['h']
desc_shuiwei_p['title']['pos'] = (0.03*desc_shuiwei_p['bimage']['w'], 
                                  0.03*desc_shuiwei_p['bimage']['w'])
desc_shuiwei_p['text']['pos'] = (0.03*desc_shuiwei_p['bimage']['w'], 
                                 1.12*(desc_shuiwei_p['title']['pos'][1]+desc_shuiwei_p['title']['fsize']))




#卡池情况描述样式
desc_pool_p = {
    'pos' : (desc_star_p['bimage']['w']+desc_star_p['bimage']['pos'][0], pie_p_pos_y),
    'w':pie_star_p['h']*desc_w_prop,
    'h':pie_star_p['h'],
    'color':'brown',
    'fsize':desc_star_p['text']['fsize']
}
desc_pool_p['fsize'] = desc_text_fsize_prop * desc_pool_p['h']

#水位情况描述样式

"""

角色框样式参数

"""

def get_char_drawer_h(line_cnt):
    return int(\
        char_title_p['fsize']+2*indi_char_drawer_p['step']+line_cnt*(indi_char_drawer_p['step']+indi_char_drawer_p['h'])\
            )

#一个drawer 46%的空间
w_prop = 0.482
line_prop = 0.12
#整个大的角色框样式参数
char_drawer_p = {
    'w':base_img_w/2.1,
    'h':get_char_drawer_h,#需要在制图时重新赋值
    'pos_newchar':((0.5-w_prop)/2*base_img_w,base_img_h),#x,y
    'pos_star6char':((0.5+(0.5-w_prop)/2)*base_img_w,base_img_h),
    'bcolor':img_bcolor#x,y
}

#大角色框标题样式
char_title_p = {
    'fsize':0.07*base_img_h,
    'pos':(0.02*char_drawer_p['w'],
           0.02*char_drawer_p['w']),
    'color':text_fcolor
}

#每行角色框的高度参数
line_prop = 0.2

#一行两个drawer的样式
indi_w_prop = 0.475#单个drawer的宽度占比

def get_line_drawer_pos0(line):
    #根据行数获取linedrawer的摆放位置
    return (int((0.5-indi_w_prop)/2*char_drawer_p['w']), 
            char_title_p['fsize']+2*indi_char_drawer_p['step']+line*(indi_char_drawer_p['step']+indi_char_drawer_p['h']))

def get_line_drawer_pos1(line):
    #根据行数获取linedrawer的摆放位置
    return (int((0.5+(0.5-indi_w_prop)/2)*char_drawer_p['w']), 
            char_title_p['fsize']+2*indi_char_drawer_p['step']+line*(indi_char_drawer_p['step']+indi_char_drawer_p['h']))

step_prop = 0.02
indi_char_drawer_p = {
    'h':line_prop*base_img_h,
    'w':indi_w_prop*char_drawer_p['w'],#稍微让出一些地方
    'pos0':get_line_drawer_pos0,
    'pos1':get_line_drawer_pos1,
    'step':step_prop*base_img_h,
    'bcolor':(190,190,190)
}
#头像及文字的样式
profile_prop = 0.75
profile_pos_y = int((1-profile_prop)/2*indi_char_drawer_p['h'])
profile_w = int(profile_prop*indi_char_drawer_p['h'])
char_text_p = {
    'profile_w':profile_w,
    'profile_pos':(profile_pos_y*0.3, profile_pos_y),
    'char_name_fsize':int(0.19*indi_char_drawer_p['h']),
    'char_name_color':title_fcolor,
    'char_desc_fsize':int(0.17*indi_char_drawer_p['h']),
    'char_desc_color':text_fcolor,
}
char_text_p['name_pos'] = (profile_pos_y*1.5+profile_w,
                                profile_pos_y)
char_text_p['desc_pos'] = (profile_pos_y*1.5+profile_w,
                                profile_pos_y+char_text_p['char_name_fsize']+0.05*indi_char_drawer_p['h'])


style_params = [title_p, sub_title_p, pie_star_p, 
                desc_star_p, desc_pool_p, histo_pool_p, desc_shuiwei_p,
                char_drawer_p, char_title_p, 
                indi_char_drawer_p, char_text_p]
#全部置为int

def parseint(params):
    for k in params:
        if type(params[k]) == int or type(params[k]) == float:
            params[k] = int(params[k])
        elif type(params[k]) == tuple:
            params[k] = tuple(map(int, params[k]))
        elif type(params[k]) == dict:
            parseint(params[k])
    return

for params in style_params:
    parseint(params)    
print('end setting')

==> nonebot_ark_record-1.0.2.tar.gz: nonebot_ark_record-1.0.2/nonebot_ark_record/ark/ark_style.py <==
"""_summary_
本文件控制绘图样式
非常不建议修改本文件中的内容
"""


"""输出图片的样式"""
#图像宽度
base_img_w = 1000
#不包括新干员信息的图像高度
base_img_h = 400

base_img_back_color = "#696969"#(125,125,125)#底图颜色
img_bcolor = '#828282'
title_fcolor = 'brown'
text_fcolor = 'black'
#
title_drawer_p = {
    'w':'',
    'h':'',
    'pos':(0,0),#直接0,0，可以不用调
    'back_img_w' :'',    
    'back_img_h' :'',
    'back_img_pos':(0,0)    
}

title_fsize_prop = 0.1
title_pos_prop = 0.1
title_p = {
    'fsize': title_fsize_prop*base_img_h,
    'color':'white'
}
title_p['pos']=(0.05*title_p['fsize'],0.1*title_p['fsize'])

sub_title_fsize_prop = 0.75
sub_title_pos_prop = 1.2
sub_title_p = {
    'fsize':sub_title_fsize_prop*title_p['fsize'],
    'color':text_fcolor,
    'pos':(title_p['pos'][0], sub_title_pos_prop*title_p['fsize'])
}

pie_p_pos_y = 1.2*(sub_title_p['fsize'] + title_p['fsize'])
x_step = 0.009*base_img_w#每个块之间的间隔

pie_p_title_fsize_prop = 0.14
pie_p_text_fsize_prop = 0.11
pie_p_percent_fsize_prop = 0.07
#设置字体大小时要考虑缩放

pie_star_p ={
    'h':240,
    'pos':(x_step, pie_p_pos_y),
    'title_fcolor':title_fcolor,
    'text_fcolor':text_fcolor,
    'percent_fcolor':text_fcolor,
    'radii': 14,
    'bcolor': img_bcolor
}
pie_star_p['w'] = pie_star_p['h']
pie_star_p['title_fsize'] = pie_star_p['h']*pie_p_title_fsize_prop
pie_star_p['text_fsize'] = pie_star_p['h']*pie_p_text_fsize_prop
pie_star_p['percent_fsize'] = pie_star_p['h']*pie_p_percent_fsize_prop

#直方图样式
histo_pool_p = {
    'pos':(pie_star_p['w']+pie_star_p['pos'][0]+x_step, pie_p_pos_y),
    'w':pie_star_p['h']*7/6,
    'h':pie_star_p['h'],
    'title_fsize':pie_star_p['title_fsize'],
    'title_fcolor':title_fcolor,
    'tick_fsize':pie_star_p['text_fsize'],
    'tick_fcolor':text_fcolor,
    'radii': 14,
    'bcolor':img_bcolor
}


#星级描述样式
desc_title_fsize_prop = 0.11
desc_text_fsize_prop = 0.09
desc_w_prop = 0.6
desc_star_p ={
    'parts':['title', 'text'],
    'bimage':{
        'w': pie_star_p['h']*0.8,
        'h': pie_star_p['h'],
        'radii': 14,#圆角半径
        'pos': (histo_pool_p['w']+histo_pool_p['pos'][0]+x_step, pie_p_pos_y),
        'bcolor':img_bcolor
    },
    'title':{
        'color':title_fcolor,
    },
    'text':{
        'color':text_fcolor,
    }
}
desc_star_p['title']['fsize'] = desc_title_fsize_prop * desc_star_p['bimage']['h']
desc_star_p['text']['fsize'] = desc_text_fsize_prop * desc_star_p['bimage']['h']
desc_star_p['title']['pos'] = (0.03*desc_star_p['bimage']['w'], 0.03*desc_star_p['bimage']['w'])
desc_star_p['text']['pos'] = (0.03*desc_star_p['bimage']['w'], 1.12*(desc_star_p['title']['pos'][1]+desc_star_p['title']['fsize']))
#水位情况

desc_shuiwei_p ={
    'parts':['title', 'text'],
    'bimage':{
        'w': pie_star_p['h']*0.95,
        'h': pie_star_p['h'],
        'radii': 14,#圆角半径
        'pos': (desc_star_p['bimage']['w']+desc_star_p['bimage']['pos'][0]+x_step, pie_p_pos_y),
        'bcolor':img_bcolor
    },
    'title':{
        'color':title_fcolor,
    },
    'text':{
        'color':text_fcolor,
    }
}
desc_shuiwei_p['title']['fsize'] = desc_title_fsize_prop * pie_star_p['h']
desc_shuiwei_p['text']['fsize'] = desc_text_fsize_prop *pie_star_p['h']
desc_shuiwei_p['title']['pos'] = (0.03*desc_shuiwei_p['bimage']['w'], 
                                  0.03*desc_shuiwei_p['bimage']['w'])
desc_shuiwei_p['text']['pos'] = (0.03*desc_shuiwei_p['bimage']['w'], 
                                 1.12*(desc_shuiwei_p['title']['pos'][1]+desc_shuiwei_p['title']['fsize']))




#卡池情况描述样式
desc_pool_p = {
    'pos' : (desc_star_p['bimage']['w']+desc_star_p['bimage']['pos'][0], pie_p_pos_y),
    'w':pie_star_p['h']*desc_w_prop,
    'h':pie_star_p['h'],
    'color':'brown',
    'fsize':desc_star_p['text']['fsize']
}
desc_pool_p['fsize'] = desc_text_fsize_prop * desc_pool_p['h']

#水位情况描述样式

"""

角色框样式参数

"""

def get_char_drawer_h(line_cnt):
    return int(\
        char_title_p['fsize']+2*indi_char_drawer_p['step']+line_cnt*(indi_char_drawer_p['step']+indi_char_drawer_p['h'])\
            )

#一个drawer 46%的空间
w_prop = 0.482
line_prop = 0.12
#整个大的角色框样式参数
char_drawer_p = {
    'w':base_img_w/2.1,
    'h':get_char_drawer_h,#需要在制图时重新赋值
    'pos_newchar':((0.5-w_prop)/2*base_img_w,base_img_h),#x,y
    'pos_star6char':((0.5+(0.5-w_prop)/2)*base_img_w,base_img_h),
    'bcolor':img_bcolor,#x,y
    'radii':15
}

#大角色框标题样式
char_title_p = {
    'fsize':0.07*base_img_h,
    'pos':(0.02*char_drawer_p['w'],
           0.02*char_drawer_p['w']),
    'color':text_fcolor
}

#每行角色框的高度参数
line_prop = 0.2

#一行两个drawer的样式
indi_w_prop = 0.475#单个drawer的宽度占比

def get_line_drawer_pos0(line):
    #根据行数获取linedrawer的摆放位置
    return (int((0.5-indi_w_prop)/2*char_drawer_p['w']), 
            char_title_p['fsize']+2*indi_char_drawer_p['step']+line*(indi_char_drawer_p['step']+indi_char_drawer_p['h']))

def get_line_drawer_pos1(line):
    #根据行数获取linedrawer的摆放位置
    return (int((0.5+(0.5-indi_w_prop)/2)*char_drawer_p['w']), 
            char_title_p['fsize']+2*indi_char_drawer_p['step']+line*(indi_char_drawer_p['step']+indi_char_drawer_p['h']))

step_prop = 0.02
indi_char_drawer_p = {
    'h':line_prop*base_img_h,
    'w':indi_w_prop*char_drawer_p['w'],#稍微让出一些地方
    'pos0':get_line_drawer_pos0,
    'pos1':get_line_drawer_pos1,
    'step':step_prop*base_img_h,
    'bcolor':(190,190,190)
}
#头像及文字的样式
profile_prop = 0.75
profile_pos_y = int((1-profile_prop)/2*indi_char_drawer_p['h'])
profile_w = int(profile_prop*indi_char_drawer_p['h'])
char_text_p = {
    'profile_w':profile_w,
    'profile_pos':(profile_pos_y*0.3, profile_pos_y),
    'char_name_fsize':int(0.19*indi_char_drawer_p['h']),
    'char_name_color':title_fcolor,
    'char_desc_fsize':int(0.17*indi_char_drawer_p['h']),
    'char_desc_color':text_fcolor,
}
char_text_p['name_pos'] = (profile_pos_y*1.5+profile_w,
                                profile_pos_y)
char_text_p['desc_pos'] = (profile_pos_y*1.5+profile_w,
                                profile_pos_y+char_text_p['char_name_fsize']+0.05*indi_char_drawer_p['h'])


style_params = [title_p, sub_title_p, pie_star_p, 
                desc_star_p, desc_pool_p, histo_pool_p, desc_shuiwei_p,
                char_drawer_p, char_title_p, 
                indi_char_drawer_p, char_text_p]
#全部置为int

def parseint(params):
    for k in params:
        if type(params[k]) == int or type(params[k]) == float:
            params[k] = int(params[k])
        elif type(params[k]) == tuple:
            params[k] = tuple(map(int, params[k]))
        elif type(params[k]) == dict:
            parseint(params[k])
    return

for params in style_params:
    parseint(params)
